[asterisk-commits] mmichelson: branch group/ccss_failure_response r296862 - in /team/group/ccss_...

SVN commits to the Asterisk project asterisk-commits at lists.digium.com
Tue Nov 30 17:49:17 CST 2010


Author: mmichelson
Date: Tue Nov 30 17:49:13 2010
New Revision: 296862

URL: http://svnview.digium.com/svn/asterisk?view=rev&rev=296862
Log:
Initial cosmetic change to the callback name.


Modified:
    team/group/ccss_failure_response/channels/chan_sip.c
    team/group/ccss_failure_response/include/asterisk/ccss.h
    team/group/ccss_failure_response/main/ccss.c

Modified: team/group/ccss_failure_response/channels/chan_sip.c
URL: http://svnview.digium.com/svn/asterisk/team/group/ccss_failure_response/channels/chan_sip.c?view=diff&rev=296862&r1=296861&r2=296862
==============================================================================
--- team/group/ccss_failure_response/channels/chan_sip.c (original)
+++ team/group/ccss_failure_response/channels/chan_sip.c Tue Nov 30 17:49:13 2010
@@ -1601,7 +1601,7 @@
 static int sip_cc_agent_init(struct ast_cc_agent *agent, struct ast_channel *chan);
 static int sip_cc_agent_start_offer_timer(struct ast_cc_agent *agent);
 static int sip_cc_agent_stop_offer_timer(struct ast_cc_agent *agent);
-static void sip_cc_agent_ack(struct ast_cc_agent *agent);
+static void sip_cc_agent_respond(struct ast_cc_agent *agent);
 static int sip_cc_agent_status_request(struct ast_cc_agent *agent);
 static int sip_cc_agent_start_monitoring(struct ast_cc_agent *agent);
 static int sip_cc_agent_recall(struct ast_cc_agent *agent);
@@ -1612,7 +1612,7 @@
 	.init = sip_cc_agent_init,
 	.start_offer_timer = sip_cc_agent_start_offer_timer,
 	.stop_offer_timer = sip_cc_agent_stop_offer_timer,
-	.ack = sip_cc_agent_ack,
+	.respond = sip_cc_agent_respond,
 	.status_request = sip_cc_agent_status_request,
 	.start_monitoring = sip_cc_agent_start_monitoring,
 	.callee_available = sip_cc_agent_recall,
@@ -1713,7 +1713,7 @@
 	return 0;
 }
 
-static void sip_cc_agent_ack(struct ast_cc_agent *agent)
+static void sip_cc_agent_respond(struct ast_cc_agent *agent)
 {
 	struct sip_cc_agent_pvt *agent_pvt = agent->private_data;
 

Modified: team/group/ccss_failure_response/include/asterisk/ccss.h
URL: http://svnview.digium.com/svn/asterisk/team/group/ccss_failure_response/include/asterisk/ccss.h?view=diff&rev=296862&r1=296861&r2=296862
==============================================================================
--- team/group/ccss_failure_response/main/ccss.c (original)
+++ team/group/ccss_failure_response/main/ccss.c Tue Nov 30 17:49:13 2010
@@ -2205,7 +2205,7 @@
 	ast_assert(callbacks->init != NULL);
 	ast_assert(callbacks->start_offer_timer != NULL);
 	ast_assert(callbacks->stop_offer_timer != NULL);
-	ast_assert(callbacks->ack != NULL);
+	ast_assert(callbacks->respond != NULL);
 	ast_assert(callbacks->status_request != NULL);
 	ast_assert(callbacks->start_monitoring != NULL);
 	ast_assert(callbacks->callee_available != NULL);
@@ -2267,7 +2267,7 @@
 static int cc_generic_agent_init(struct ast_cc_agent *agent, struct ast_channel *chan);
 static int cc_generic_agent_start_offer_timer(struct ast_cc_agent *agent);
 static int cc_generic_agent_stop_offer_timer(struct ast_cc_agent *agent);
-static void cc_generic_agent_ack(struct ast_cc_agent *agent);
+static void cc_generic_agent_respond(struct ast_cc_agent *agent);
 static int cc_generic_agent_status_request(struct ast_cc_agent *agent);
 static int cc_generic_agent_stop_ringing(struct ast_cc_agent *agent);
 static int cc_generic_agent_start_monitoring(struct ast_cc_agent *agent);
@@ -2279,7 +2279,7 @@
 	.init = cc_generic_agent_init,
 	.start_offer_timer = cc_generic_agent_start_offer_timer,
 	.stop_offer_timer = cc_generic_agent_stop_offer_timer,
-	.ack = cc_generic_agent_ack,
+	.respond = cc_generic_agent_respond,
 	.status_request = cc_generic_agent_status_request,
 	.stop_ringing = cc_generic_agent_stop_ringing,
 	.start_monitoring = cc_generic_agent_start_monitoring,
@@ -2403,7 +2403,7 @@
 	return 0;
 }
 
-static void cc_generic_agent_ack(struct ast_cc_agent *agent)
+static void cc_generic_agent_respond(struct ast_cc_agent *agent)
 {
 	/* The generic agent doesn't have to do anything special to
 	 * acknowledge a CC request. Just return.
@@ -2806,7 +2806,7 @@
 	 *    call monitor's unsuspend callback.
 	 */
 	if (previous_state == CC_CALLER_REQUESTED) {
-		core_instance->agent->callbacks->ack(core_instance->agent);
+		core_instance->agent->callbacks->respond(core_instance->agent);
 		manager_event(EVENT_FLAG_CC, "CCRequestAcknowledged",
 			"CoreID: %d\r\n"
 			"Caller: %s\r\n",




More information about the asterisk-commits mailing list
--- team/group/ccss_failure_response/include/asterisk/ccss.h (original)
+++ team/group/ccss_failure_response/include/asterisk/ccss.h Tue Nov 30 17:49:13 2010
@@ -920,19 +920,22 @@
 	 */
 	int (*stop_offer_timer)(struct ast_cc_agent *agent);
 	/*!
 	 * \brief Acknowledge CC request.
 	 *
 	 * \param agent CC core agent control.
 	 *
 	 * \details
 	 * When the core receives knowledge that a called
 	 * party has accepted a CC request, it will call
-	 * this callback.
-	 *
-	 * The duty of this is to accept a CC request from
-	 * the caller by acknowledging receipt of that request.
-	 */
-	void (*ack)(struct ast_cc_agent *agent);
+	 * this callback. The core may also call this
+	 * if there is some error when attempting to process
+	 * the incoming CC request.
+	 *
+	 * The duty of this is to isse a proper response to a
+	 * CC request from the caller by acknowledging receipt
+	 * of that request or rejecting it.
+	 */
+	void (*respond)(struct ast_cc_agent *agent);
 	/*!
 	 * \brief Request the status of the agent's device.
 	 *
@@ -920,19 +920,22 @@
 	int (*stop_offer_timer)(struct ast_cc_agent *agent);
 	/*!
-	 * \brief Acknowledge CC request.
+	 * \brief Respond to a CC request.
 	 *
 	 * \param agent CC core agent control.

Modified: team/group/ccss_failure_response/main/ccss.c
URL: http://svnview.digium.com/svn/asterisk/team/group/ccss_failure_response/main/ccss.c?view=diff&rev=296862&r1=296861&r2=296862
==============================================================================